@@ -1,9 +1,8 @@
 import os
 import sys
-import argparse
 
-from .log import logger
-from .settings import args
+from pyway.log import logger
+#from pyway.settings import args
 
 
 def _dir_maker(dir_):
@@ -11,8 +10,8 @@ def _dir_maker(dir_):
         logger.info("%s not found, creating local folder" % dir_)
         os.makedirs(dir_)
 
-if args.log_to_file:
-    _dir_maker(settings.args.logs_dir)
+#if args.log_to_file:
+#    _dir_maker(settings.args.logs_dir)
 
-_dir_maker(settings.args.database_migration_dir)
+#_dir_maker(settings.args.database_migration_dir)
 
