@@ -1,44 +1,48 @@
 import sys
 
-from pyway import settings
+from pyway.settings import Settings
 from pyway.info import Info
 from pyway.log import logger
 from pyway.migrate import Migrate
 from pyway.validate import Validate
 from pyway.import_ import Import
+from pyway.version import __version__
 
-def migrate():
+def migrate(args):
     logger.info('Starting migration process...')
-    Migrate(settings).run()
+    Migrate(args).run()
     logger.info('Migration completed.')
 
 
-def validate():
+def validate(args):
     logger.info('Starting validation process')
-    Validate(settings).run()
+    Validate(args).run()
     logger.info('Validation completed.')
 
 
-def info():
+def info(args):
     logger.info('Gathering info...')
-    Info(settings).run()
+    Info(args).run()
     print()
 
-def import_():
+def import_(args):
     logger.info("Importing schema...")
-    Import(settings).run()
+    Import(args).run()
 
 def cli():
-    logger.info(settings.LOGO)
+    logger.info(f"PyWay {__version__}")
 
-    if settings.args.cmd == "info":
-        info()
-    elif settings.args.cmd == "validate":
-        validate()
-    elif settings.args.cmd == "migrate":
-        migrate()
-    elif settings.args.cmd == "import":
-        import_();
+    args = Settings.parse_arguments()
+    args = Settings.parse_config_file(args)
+
+    if args.cmd == "info":
+        info(args)
+    elif args.cmd == "validate":
+        validate(args)
+    elif args.cmd == "migrate":
+        migrate(args)
+    elif args.cmd == "import":
+        import_(args)
     else:
         logger.error(f"Command '{settings.args.cmd}' not recognized, exiting!")
         sys.exit(1)
